@@ -1,4 +1,4 @@
-package LSF::JobManager; $VERSION = 0.4;
+package LSF::JobManager; $VERSION = 0.5;
 
 use strict;
 use warnings;
@@ -46,15 +46,15 @@ sub submit{
 # the terminal) and a dependancy expression that tests that all
 # the previously submitted LSF jobs have ended (any exit status)
 sub wait_all_children{
-    my ($this,$custom_dependancy) = @_;
+    my ($this,%options) = @_;
     my @jobs = $this->jobs;
     unless(@jobs){
         warn "No LSF::Job's in this LSF::Manager\n" if $this->PrintError;
         return;
     }
     my $dependancy;
-    if($custom_dependancy){
-        $dependancy = $custom_dependancy;
+    if(exists $options{depend}){
+        $dependancy = $options{depend};
     }else{
         for(@jobs){
             $dependancy .= "ended($_)&&";
@@ -65,11 +65,19 @@ sub wait_all_children{
     my $job = LSF::Job->submit_top( new_flags( [ $this->params ],['-I',-w => $dependancy])
                                               ,"echo LSF::JobManager finished waiting for " . scalar @jobs . " jobs" );
     
+	$options{history} = 1 unless exists $options{history};
+    $this->cache_history if $options{history};
+    return;
+}
+
+sub cache_history{
     # batch run the history of each job b/c its much quicker this way.
     # because we may have more jobs than the arg list allows then we have a 
     # second syntax for calling LSF::JobHistory->new
     # if the first argument is and array reference then 
     # see JobHistory.pm for details but basically we use xargs
+	my $this = shift;
+    my @jobs = $this->jobs;
     my @history = LSF::JobHistory->new([],@jobs);
     my %jobs = %{ $this->{-jobs} };
     for my $hist (@history){
@@ -157,10 +165,10 @@ LSF::JobManager - submit and wait for a set of LSF Jobs
         $job->top;
     }
     
-    $m->wait_all_children;
+    $m->wait_all_children( history => 1 );
     print "All children have completed!\n";
 
-    for my $job ($m->jobs){
+    for my $job ($m->jobs){ # much quicker if history is pre-cached
         print STDERR "$job exited non zero\n" if $job->history->exit_status != 0;
     }
     
@@ -202,7 +210,7 @@ call. The required argument is the command line to submit. Optional arguments
 override the defaults given to C<new>. The submitted LSF::Job object is returned
 on success, otherwise undef is returned, $? and $@ set. See C<LSF::Job>
 
-=item $manager->wait_all_children( [ DEPENDANCY ] )
+=item $manager->wait_all_children( [ depend => DEPENDANCY, history => 1 ] )
 
 Waits for all previously submitted LSF Jobs to complete in a blocking manner.
 
@@ -211,7 +219,14 @@ an autogenerated dependancy based on the job id's of all the submitted jobs.
 In conjunction with named jobs ( the -J flag ) this can be used to get around
 the shell arg length limit which can be hit by extremely long dependancy 
 expressions. See the L<bsub> documentation for details of job names and 
-depenancy expressions
+depenancy expressions.
+
+If the history flag is used to pass a true value then after all jobs have 
+completed the history of each job is fetched in batch. It is much quicker
+this way than fetching each job history separately. The time taken is still 
+significant however. If you do not intend to check the exit status or the
+command line or any other property of the Job::History object then it is worth
+passing a false value and avoiding the overhead.
 
 =item $manager->params( [ [ PARAMS ] ] )
 
