@@ -1,53 +1,50 @@
-package LSF::Queue; $VERSION = 0.2;
+package LSF::Queue; $VERSION = 0.3;
 
+use strict;
+use warnings;
 use base qw( LSF );
 use IPC::Run qw( run );
 
 sub import{
-    my $self = shift;
-    my %params = @_;
-    $self->print($params{PRINT}) if exists $params{PRINT};
+    my ($self, %p) = @_;
+    $p{RaiseError}  ||= 1;
+    $p{PrintOutput} ||= 1;
+    $p{PrintError}  ||= 1;
+    $self->PrintOutput($p{PrintOutput}) if exists $p{PrintOutput};
+    $self->PrintError ($p{PrintError} ) if exists $p{PrintError};
+    $self->RaiseError ($p{RaiseError} ) if exists $p{RaiseError};
 }
 
 sub new{
     my($class,@params) = @_;
-    my ($out,$err);
-    @params = grep { $_ ne '-l' } @params;
-    run ['bqueues','-l',@params],\undef,\$out,\$err;
-    if($?){
-        $@ = $err;
-        warn $@ if $class->print;
-        return ();
-    }else{
-        print $out if $class->print;
-
-        my @queue;
-        for my $text (split(/^-+$/m,$out)){
-            my $queue;
-            for ('QUEUE','USERS','HOSTS','RES_REQ','PREEMPTION',
-                 'CHKPNTDIR','CHKPNTPERIOD','CHUNK_JOB_SIZE'){
-                if( $text =~ /^($_):\s+(.+)$/m ){
-                    $queue->{$1} = $2;
-                }
+    my @output = $class->do_it('bqueues','-l',@params);
+    return unless @output;
+    my @queue;
+    for my $text (split(/^-+$/m,$output[0])){
+        my $queue;
+        for ('QUEUE','USERS','HOSTS','RES_REQ','PREEMPTION',
+             'CHKPNTDIR','CHKPNTPERIOD','CHUNK_JOB_SIZE'){
+            if( $text =~ /^($_):\s+(.+)$/m ){
+                $queue->{$1} = $2;
             }
-            $text =~ /^  -- (.+)$/m;
-            $queue->{DESC} = $1;
-            for ('MEMLIMIT','PROCLIMIT','CPULIMIT'){
-                if( $text =~ /\n ($_)\n ([^\n]+)/ ){
-                    $queue->{$1} = $2;
-                }
-            }
-            $text =~ /PARAMETERS\/STATISTICS\n([^\n]+)\n\s*([^\n]+)/;
-            my @keys = split(/\s+/,$1);
-            my @vals = split(/\s+/,$2);
-            for( my $i = 0; $i < @keys; $i++ ){
-                $queue->{$keys[$i]} = $vals[$i];
-            }
-            bless $queue, $class;
-            push @queue,$queue;
         }
-        return @queue;
+        $text =~ /^  -- (.+)$/m;
+        $queue->{DESC} = $1;
+        for ('MEMLIMIT','PROCLIMIT','CPULIMIT'){
+            if( $text =~ /\n ($_)\n ([^\n]+)/ ){
+                $queue->{$1} = $2;
+            }
+        }
+        $text =~ /PARAMETERS\/STATISTICS\n([^\n]+)\n\s*([^\n]+)/;
+        my @keys = split(/\s+/,$1);
+        my @vals = split(/\s+/,$2);
+        for( my $i = 0; $i < @keys; $i++ ){
+            $queue->{$keys[$i]} = $vals[$i];
+        }
+        bless $queue, $class;
+        push @queue,$queue;
     }
+    return @queue;
 }
 
 1;
@@ -62,9 +59,9 @@ LSF::Queue - get information about LSF queues.
 
 use LSF::Queue;
 
-use LSF::Queue PRINT => 1;
+use LSF::Queue RaiseError => 0, PrintError => 1, PrintOutput => 0;
 
-$qinfo = LSF::Queue->new( [QUEUE_NAME] );
+($qinfo) = LSF::Queue->new( [QUEUE_NAME] );
 
 @qinfo = LSF::Queue->new();
 
@@ -74,6 +71,10 @@ C<LSF::Queue> is a wrapper arround the LSF 'bqueues' command used to obtain
 information about job queues. The hash keys of the object are LSF submission
 and control parameters. See the 'bqueues' man page for more information.
 
+=head1 INHERITS FROM
+
+B<LSF>
+
 =head1 CONSTRUCTOR
 
 =over 4
@@ -86,18 +87,24 @@ Arguments are the LSF parameters normally passed to 'bqueues'
 
 =head1 BUGS
 
-Please report them. 
+The use of the '-l' flag of the LSF command lines can be considered a bug.
 The parsing of LSF output is particularly unsafe if job and group names with 
 non-alphanumeric characters are used. You probably shouldn't be doing this
 anyway.
+Otherwise, please report them.
 
 =head1 HISTORY
 
-The LSF::Batch module on cpan didn't compile easily on all platforms i wanted.
+The B<LSF::Batch> module on cpan didn't compile easily on all platforms i wanted.
 The LSF API didn't seem very perlish either. As a quick fix I knocked these
 modules together which wrap the LSF command line interface. It was enough for
 my simple usage. Hopefully they work in a much more perly manner.
 
+=head1 SEE ALSO
+
+L<LSF>,
+L<bqueues>
+
 =head1 AUTHOR
 
 Mark Southern (mark_southern@merck.com)
